# Most cores don't require a BIOS/copyrighted material, so it can go in core.

%define major   2
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

Name:           mupen64plus
Version:        2.6.0
Release:        %mkrel 6
Summary:        Nintendo 64 Emulator (console frontend)
License:        GPLv2+ and LGPLv2+
Group:          Emulators
URL:            https://www.mupen64plus.org
Source0:        https://github.com/mupen64plus/mupen64plus-core/releases/download/%{version}/%{name}-bundle-src-%{version}.tar.gz
Patch0:         mupen64plus-use-system-font.patch
Patch1:         mupen64plus-arm32.patch

BuildRequires:  boost-devel
BuildRequires:  lirc-devel
BuildRequires:  nasm
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(speexdsp)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(vulkan)
Requires:       fonts-ttf-dejavu
Requires:       %{libname} = %{version}-%{release}

%description
Mupen64Plus is a cross-platform plugin-based Nintendo 64 emulator which is
capable of accurately playing many games. Included are four MIPS R4300 CPU
emulators, with dynamic recompilers for 32-bit x86 and 64-bit amd64 systems,
and necessary plugins for audio, graphical rendering (RDP), signal
co-processor (RSP), and input.

%files
%license source/mupen64plus-core/LICENSES
%doc source/mupen64plus-core/{README,RELEASE}
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.*
%{_mandir}/man6/%{name}.6*

#----------------------------------------------------------------------------

%package -n     %{libname}
Summary:        Main library for Mupen64Plus Nintendo 64 Emulator
Group:          System/Libraries
Recommends:     m64py

%description -n %{libname}
Mupen64Plus is a cross-platform plugin-based Nintendo 64 emulator which is
capable of accurately playing many games. Included are four MIPS R4300 CPU
emulators, with dynamic recompilers for 32-bit x86 and 64-bit amd64 systems,
and necessary plugins for audio, graphical rendering (RDP), signal
co-processor (RSP), and input.

This package contains the shared library interface for Mupen64Plus frontends
and all plugins from the upstream project.

%files -n       %{libname}
%license source/mupen64plus-core/LICENSES
%{_libdir}/lib%{name}.so.%{major}{,.*}
%{_libdir}/%{name}/

#----------------------------------------------------------------------------

%package -n     %{devname}
Summary:        Development headers for Mupen64Plus Nintendo 64 Emulator
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
Mupen64Plus is a cross-platform plugin-based Nintendo 64 emulator which is
capable of accurately playing many games. Included are four MIPS R4300 CPU
emulators, with dynamic recompilers for 32-bit x86 and 64-bit amd64 systems,
and necessary plugins for audio, graphical rendering (RDP), signal
co-processor (RSP), and input.

This package contains all necessary include files to develop frontends
against the Mupen64Plus shared library interface.

%files -n       %{devname}
%{_includedir}/%{name}/

#----------------------------------------------------------------------------

%prep
%autosetup -p1 -n %{name}-bundle-src-%{version}

# We use the system's font instead of the shipped one
rm source/mupen64plus-core/data/font.ttf

%build
OPTFLAGS="%{optflags}" \
LDFLAGS="%{ldflags}" \
./m64p_build.sh LIBDIR=%{_libdir} PLUGINDIR=%{_libdir}/%{name} \
                PIC=1 \
                LIRC=1 \
%ifnarch %{ix86} x86_64
                NO_SSE=1 \
%endif
                V=1 \
                %{_smp_mflags}

%install
./m64p_install.sh DESTDIR=%{buildroot} \
                  PREFIX=%{_prefix} \
                  LIBDIR=%{_libdir} \
                  MANDIR=%{_mandir} \
                  INSTALL_STRIP_FLAG=''

# ensure libraries/modules are executable (mga#24160#c4)
chmod a+rx %{buildroot}%{_libdir}/lib%{name}.so.%{major}*
chmod a+rx %{buildroot}%{_libdir}/%{name}/*.so


%changelog
* Mon Jun 30 2025 umeabot <umeabot> 2.6.0-6.mga10
+ Revision: 2231452
- Mageia 10 Mass Rebuild

* Fri Dec 13 2024 wally <wally> 2.6.0-5.mga10
+ Revision: 2124747
- define LIBDIR when building to fix dlopening the lib

* Fri Dec 13 2024 wally <wally> 2.6.0-4.mga10
+ Revision: 2124736
- fix armv7hl build
  * add missing include for header file
  * don't override our build cflags

* Wed Dec 11 2024 daviddavid <daviddavid> 2.6.0-3.mga10
+ Revision: 2123434
- try to fix build on arm

* Mon Dec 09 2024 eatdirt <eatdirt> 2.6.0-2.mga10
+ Revision: 2123179
- Rebuild for new boost

* Thu Aug 15 2024 daviddavid <daviddavid> 2.6.0-1.mga10
+ Revision: 2086639
- new version: 2.6.0

* Fri Jun 21 2024 daviddavid <daviddavid> 2.5.9-12.mga10
+ Revision: 2075999
- add opensuse patch to fix build with boost 1.85
+ wally <wally>
- rebuild for boost 1.85.0

* Fri Jan 12 2024 wally <wally> 2.5.9-11.mga10
+ Revision: 2030571
- rebuild for boost 1.84.0

* Wed Sep 27 2023 wally <wally> 2.5.9-10.mga10
+ Revision: 1991474
- rebuild for boost 1.83.0

* Sat Dec 24 2022 wally <wally> 2.5.9-9.mga9
+ Revision: 1926507
- rebuild for boost 1.81.0

* Sun Jul 03 2022 wally <wally> 2.5.9-8.mga9
+ Revision: 1867287
- rebuild for boost 1.79.0

* Tue Apr 05 2022 umeabot <umeabot> 2.5.9-7.mga9
+ Revision: 1845454
- Mageia 9 Mass Rebuild

* Sun Dec 19 2021 wally <wally> 2.5.9-6.mga9
+ Revision: 1762660
- rebuild for boost 1.78.0

* Thu Sep 09 2021 wally <wally> 2.5.9-5.mga9
+ Revision: 1744603
- rebuild for boost 1.77.0

* Fri May 14 2021 wally <wally> 2.5.9-4.mga9
+ Revision: 1722994
- rebuild for boost 1.76.0

* Thu Dec 31 2020 wally <wally> 2.5.9-3.mga8
+ Revision: 1666790
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 2.5.9-2.mga8
+ Revision: 1662032
- rebuild for boost 1.74.0

* Tue Nov 03 2020 akien <akien> 2.5.9-1.mga8
+ Revision: 1642083
- Re-add patch to fix aarch64 build, one plugin left without explicit support
- Version 2.5.9, now built in core as it doesn't require copyrighted material

* Sun May 03 2020 wally <wally> 2.5-12.mga8.tainted
+ Revision: 1578086
- rebuild for boost 1.73.0

* Fri Feb 21 2020 umeabot <umeabot> 2.5-11.mga8.tainted
+ Revision: 1548882
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 2.5-10.mga8.tainted
+ Revision: 1483403
- rebuild for boost 1.72.0

* Sat Jul 27 2019 daviddavid <daviddavid> 2.5-9.mga8.tainted
+ Revision: 1424576
- libraries and modules should be executable (mga#24160#c4)
+ wally <wally>
- build using our ldflags

* Fri Oct 19 2018 wally <wally> 2.5-8.mga7.tainted
+ Revision: 1322311
- add patch for aarch64 support
- rebuild for new boost 1.68.0

* Thu Sep 20 2018 umeabot <umeabot> 2.5-7.mga7.tainted
+ Revision: 1279987
- Mageia 7 Mass Rebuild

* Mon Dec 25 2017 wally <wally> 2.5-6.mga7.tainted
+ Revision: 1184689
- rebuild for new boost

* Tue Nov 21 2017 tv <tv> 2.5-5.mga7.tainted
+ Revision: 1178335
- rebuild for boost 1.65

* Sun Sep 24 2017 daviddavid <daviddavid> 2.5-4.mga7.tainted
+ Revision: 1158413
- use our compile flags thus fixing empty debugsourcefiles.list
- rebuild for new boost 1.64.0

* Sun Oct 16 2016 pterjan <pterjan> 2.5-3.mga6.tainted
+ Revision: 1061069
- Do not disable SSE on x86_64

* Sat Oct 15 2016 pterjan <pterjan> 2.5-2.mga6.tainted
+ Revision: 1061001
- Disable SSE on !x86
- Set VFP_HARD on armv7hl to get it to start building

* Sat Jan 09 2016 akien <akien> 2.5-1.mga6.tainted
+ Revision: 920830
- Version 2.5
- Do not strip binaries, reenable debuginfo

* Sat Dec 26 2015 daviddavid <daviddavid> 2.0-11.mga6.tainted
+ Revision: 915427
- rebuild for new boost 1.60.0

* Sat Sep 26 2015 daviddavid <daviddavid> 2.0-10.mga6.tainted
+ Revision: 883943
- rebuild for new boost 1.59.0

* Sun Aug 02 2015 daviddavid <daviddavid> 2.0-9.mga6.tainted
+ Revision: 860583
- rebuild for new boost-1.58.0

* Wed Oct 15 2014 umeabot <umeabot> 2.0-8.mga5.tainted
+ Revision: 739403
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 2.0-7.mga5.tainted
+ Revision: 727385
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 2.0-6.mga5.tainted
+ Revision: 682701
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Wed Jun 04 2014 akien <akien> 2.0-5.mga5.tainted
+ Revision: 633177
- Suggest the m64py Qt4 frontend

* Tue May 20 2014 akien <akien> 2.0-4.mga5.tainted
+ Revision: 624559
- Add warning about this being a tainted package
- Do a proper libification of the package
- Add an OpenSUSE patch to use system-wide DejaVu font
- Improve description

* Mon May 19 2014 akien <akien> 2.0-3.mga5.tainted
+ Revision: 623693
- Rebuild for new boost

* Thu Oct 31 2013 tmb <tmb> 2.0-2.mga4.tainted
+ Revision: 548209
- Mageia 4 rebuild

* Thu Oct 10 2013 dams <dams> 2.0-1.mga4.tainted
+ Revision: 494543
- new version 2.0

* Mon Jun 03 2013 fwang <fwang> 1.5-5.mga4.tainted
+ Revision: 436021
- rebuild for new libpng

* Sat Jan 12 2013 umeabot <umeabot> 1.5-4.mga3.tainted
+ Revision: 360514
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Oct 31 2011 dmorgan <dmorgan> 1.5-3.mga2.tainted
+ Revision: 160275
- imported package mupen64plus


* Sun Jul 31 2011 Andrey Bondrov <abondrov@mandriva.org> 1.5-3mdv2012.0
+ Revision: 692528
- Rebuild
- Drop patch 10 as it breaks 64 bit version

* Wed Jul 27 2011 Andrey Bondrov <abondrov@mandriva.org> 1.5-2
+ Revision: 691880
- Add desktop-file-utils to BuildRequires
- Fix group
- imported package mupen64plus


* Sun Jul 23 2011 Andrey Bondrov <bondrov@math.dvgu.ru> 1.5-2mdv2011.0
- Add patches from Debian
- Add keyboard default config patch from MIB
- Import from PLF
- Remove PLF reference

* Tue Jan  6 2009 Guillaume Bedot <littletux@zarb.org> 1.5-1plf2009.1
- First package of mupen64plus for PLF, requested by Zombie Ryushu
